@@ -2,6 +2,7 @@ from __future__ import absolute_import
 from __future__ import print_function
 from __future__ import division
 
+import sys
 import tensorflow as tf
 tf.get_logger().setLevel('ERROR')
 tf.compat.v1.disable_eager_execution()
@@ -27,6 +28,12 @@ from .utils.utilities import set_random_seed
 from .utils.utilities import set_floatx
 from .utils.utilities import get_bibliography
 
+import json
+from urllib import request
+from pkg_resources import parse_version
+
+from .references import BIBLIOGRAPHY_STR
+
 # SciANN.
 __author__ = "Ehsan Haghighat"
 __email__ = "ehsanh@mit.edu"
@@ -34,7 +41,7 @@ __copyright__ = "Copyright 2019, Physics-Informed Deep Learning"
 __credits__ = []
 __url__ = "http://github.com/sciann/sciann]"
 __license__ = "MIT"
-__version__ = "0.6.3.1"
+__version__ = "0.6.7.4"
 __cite__ = \
     '@article{haghighat2021sciann, \n' +\
     '    title={SciANN: A Keras/TensorFlow wrapper for scientific computations and physics-informed deep learning using artificial neural networks}, \n' +\
@@ -57,7 +64,9 @@ __welcome__ = \
     '\n ' +\
     'Need support or would like to contribute, please join sciann`s slack group: \n' +\
     ' +  "https://join.slack.com/t/sciann/shared_invite/zt-ne1f5jlx-k_dY8RGo3ZreDXwz0f~CeA" ' +\
-    '\n ' 
+    '\n \n' +\
+    'TensorFlow Version: {} \n'.format(tf.__version__) +\
+    'Python Version: {} \n'.format(sys.version)
     # '{} \n'.format(__cite__) +\
     # _footer
 
@@ -71,4 +80,16 @@ else:
 
 # set default logging directory.
 set_default_log_path(os.path.join(os.getcwd(), "logs"))
-initialize_bib(os.path.join(os.path.dirname(__file__), 'references', 'bibliography'))
\ No newline at end of file
+initialize_bib(BIBLIOGRAPHY_STR)
+
+# check sciann version.
+try:
+    url = 'https://pypi.python.org/pypi/sciann/json'
+    releases = json.loads(request.urlopen(url, timeout=1).read())['releases']
+    releases = sorted(releases, key=parse_version, reverse=True)
+    if releases.index(__version__) > 0:
+        print(f'Outdated SciANN installation is found (V-{__version__}). '
+              f'Get the latest version (V-{releases[0]}):  \n '
+              f'     > pip [--user] install --upgrade sciann  ')
+except:
+    pass
